# biliupload

This is a Python implementation of [biliup-rs](https://github.com/biliup/biliup-rs).

From now on, I have implemented the login and upload functions, and will continue to implement the other functions. Welcome to use and give me more feedback. And welcome to contribute to this project.

